import React, {useState} from 'react';
import { useSelector, useDispatch } from "react-redux";

import Todo from "./Todo";
import {TodoItem} from "./types";
import { ADD_TODO } from "./reducers";

function App() {
    const [text, setText] = useState("");
    const todos = useSelector((state: { todos: TodoItem[] }) => state.todos);
    const dispatch = useDispatch();

    const handleAddTodo = () => {
        if (text.trim() === "") return;
        const newTodo: TodoItem = {
            id: todos.length + 1,
            text: text,
            completed: false,
        };

        dispatch({ type: ADD_TODO, payload: newTodo});
        setText("");
    }

    return (
        <div>
            <h1>Todo List</h1>
            <input
                type="text"
                value={text}
                onChange={(e) => setText(e.target.value)}
            />
            <button onClick={handleAddTodo}>Add Todo</button>
            <ul>
                {todos.map((todo) => (
                    <Todo
                        key={todo.id}
                        id={todo.id}
                        text={todo.text}
                        completed={todo.completed}
                    />
                ))}
            </ul>
        </div>
    );
}

export default App;
